<?php
/**
 * Custom and output functions for the theme customizer 
 *
 * @package    SmartZine
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'smartzine_mod' ) ) :
/**
 * Wrap get_theme_mod function
 */
function smartzine_mod( $name ) {

	$prefix = 'smartzine-';

	return apply_filters( 'tj_theme_mod', get_theme_mod( $name, customizer_library_get_default( $name ) ), $prefix, $name );

}
endif;

if ( ! function_exists( 'smartzine_textarea_stripslashes' ) ) :
/**
 * Sanitize a textarea for ads.
 *
 * @since  1.0.0
 */
function smartzine_textarea_stripslashes( $string ) {
	return stripslashes( $string );
}
endif;

/**
 * Custom customizer function.
 *
 * @since  1.0.0
 */
function smartzine_move_default_customizer( $wp_customize ) {

	// Move the customize to new panel
	$wp_customize->get_section( 'title_tagline' )->panel       = 'header';
	$wp_customize->get_section( 'static_front_page' )->panel   = 'general';
	$wp_customize->get_section( 'colors' )->panel              = 'color';
	$wp_customize->get_section( 'background_image' )->panel    = 'color';
	
	// moving Theme Layout
	$wp_customize->get_section( 'layout' )->panel              = 'content-layout';
	$wp_customize->get_section( 'layout' )->title              = __( 'Global Layout', 'smartzine' );
	$wp_customize->get_section( 'layout' )->priority           = 1;

	// Change the title/description
	$wp_customize->get_section( 'title_tagline' )->title       = __( 'Site Title', 'smartzine' );
	$wp_customize->get_section( 'title_tagline' )->description = __( 'Site title will automatically disappear if you upload a logo.', 'smartzine' );
	$wp_customize->get_section( 'colors' )->title              = __( 'Background', 'smartzine' );
	$wp_customize->get_section( 'colors' )->priority           = 1;
	$wp_customize->get_section( 'background_image' )->priority = 2;

	// Live preview
	$wp_customize->get_setting( 'blogname' )->transport        = 'postMessage';

	// Remove section
	// $wp_customize->remove_control( 'blogdescription' );
}
add_action( 'customize_register', 'smartzine_move_default_customizer', 20 );

/**
 * Retrieve tags list.
 *
 * @since  1.0.0
 * @return array $tags
 */
function smartzine_tags_list() {

	// Set up empty array.
	$tags = array();

	// Retrieve available tags.
	$tags_obj = get_tags();

	// Set default/empty tag.
	$tags[''] = __( 'Select a tag &hellip;', 'smartzine' );

	// Display the tags.
	foreach ( $tags_obj as $tag ) {
		$tags[$tag->term_id] = esc_attr( $tag->name );
	}

	return $tags;

}

/**
 * Retrieve categories list.
 *
 * @since  1.0.0
 * @return array $tags
 */
function smartzine_cats_list() {

	// Set up empty array.
	$cats = array();

	// Retrieve available categories.
	$cats_obj = get_categories();

	// Set default/empty category.
	$cats[''] = __( 'Select a category &hellip;', 'smartzine' );

	// Display the categories.
	foreach ( $cats_obj as $cat ) {
		$cats[$cat->term_id] = esc_attr( $cat->name );
	}

	return $cats;

}

/**
 * Get all registered sidebar
 *
 * @return void
 * @author tokoo
 **/
function smartzine_sidebars_list() {
	global $wp_registered_sidebars;

	// Set up empty array
	$sidebars = array();

	if ( $wp_registered_sidebars && ! is_wp_error( $wp_registered_sidebars ) ) {
		// Display the sidebars
		foreach ( $wp_registered_sidebars as $sidebar ) {
			$sidebars[$sidebar['id']] = esc_attr( $sidebar['name'] );
		}
	}
	return $sidebars;
}

/**
 * Display theme documentation on customizer page
 */
function smartzine_documentation_notice() {

	// Enqueue the script
	wp_enqueue_script(
		'smartzine-customizer-doc',
		get_template_directory_uri() . '/admin/js/doc.js',
		array(), '1.0.0',
		true
	);
 
	// Localize the script
	wp_localize_script(
		'smartzine-customizer-doc',
		'prefixL10n',
		array(
			'prefixURL'   => esc_url( 'http://docs.theme-junkie.com/smartzine' ),
			'prefixLabel' => __( 'Documentation', 'smartzine' ),
		)
	);
 
}
add_action( 'customize_controls_enqueue_scripts', 'smartzine_documentation_notice' );