<?php
/**
 * Register custom customizer panels, sections and settings.
 *
 * @package    SmartZine
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * We register our custom customizer by using the hook.
 *
 * @since  1.0.0
 */
function smartzine_customizer_register() {

	// Stores all the controls that will be added
	$options = array();

	// Stores all the sections to be added
	$sections = array();

	// Stores all the panels to be added
	$panels = array();

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// ======= Start Customizer Panels/Sections/Settings ======= //
	
	// Theme prefix
	$prefix = 'smartzine-';
	
	// General Panels and Sections
	$general_panel = 'general';

	$panels[] = array(
		'id'       => $general_panel,
		'title'    => __( 'General', 'smartzine' ),
		'priority' => 10
	);

		// Favicon
		$section = $prefix . 'favicon-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Favicon', 'smartzine' ),
			'priority'    => 35,
			'panel'       => $general_panel
		);
		$options[$prefix . 'favicon'] = array(
			'id'           => $prefix . 'favicon',
			'label'        => __( 'Favicon', 'smartzine' ),
			'section'      => $section,
			'type'         => 'image',
			'default'      => '',
			'description'  => __( 'File must be <strong>.png</strong> or <strong>.ico</strong> format. Optimal dimensions: <strong>32px x 32px</strong>.', 'smartzine' ),
		);
		$options[$prefix . 'mobile-icon'] = array(
			'id'           => $prefix . 'mobile-icon',
			'label'        => __( 'Apple Touch Icon', 'smartzine' ),
			'section'      => $section,
			'type'         => 'image',
			'default'      => '',
			'description'  => __( 'File must be <strong>.png</strong> format. Optimal dimensions: <strong>152px x 152px</strong>.', 'smartzine' ),
		);

		// RSS
		$section = $prefix . 'rss-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'RSS', 'smartzine' ),
			'priority'    => 100,
			'panel'       => $general_panel,
			'description' => __( 'If you fill the custom rss url below, it will replace the default.', 'smartzine' ),
		);
		$options[$prefix . 'custom-rss'] = array(
			'id'           => $prefix . 'custom-rss',
			'label'        => __( 'Custom RSS URL (eg. Feedburner)', 'smartzine' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);

		// Comment
		$section = $prefix . 'comment-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Comments', 'smartzine' ),
			'priority'    => 110,
			'panel'       => $general_panel,
		);
		$options[$prefix . 'page-comment'] = array(
			'id'           => $prefix . 'page-comment',
			'label'        => __( 'Page Comment', 'smartzine' ),
			'section'      => $section,
			'type'         => 'switch',
			'default'      => 1
		);

		// Social header
		$section = $prefix . 'social-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Social', 'smartzine' ),
			'priority'    => 115,
			'panel'       => $general_panel
		);
		$options[$prefix . 'twitter'] = array(
			'id'      => $prefix . 'twitter',
			'label'   => __( 'Twitter URL', 'smartzine' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[$prefix . 'facebook'] = array(
			'id'      => $prefix . 'facebook',
			'label'   => __( 'Facebook URL', 'smartzine' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[$prefix . 'gplus'] = array(
			'id'      => $prefix . 'gplus',
			'label'   => __( 'Google Plus URL', 'smartzine' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[$prefix . 'instagram'] = array(
			'id'      => $prefix . 'instagram',
			'label'   => __( 'Instagram URL', 'smartzine' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[$prefix . 'pinterest'] = array(
			'id'      => $prefix . 'pinterest',
			'label'   => __( 'Pinterest URL', 'smartzine' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[$prefix . 'tumblr'] = array(
			'id'      => $prefix . 'tumblr',
			'label'   => __( 'Tumblr URL', 'smartzine' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);
		$options[$prefix . 'rss'] = array(
			'id'      => $prefix . 'rss',
			'label'   => __( 'RSS URL', 'smartzine' ),
			'section' => $section,
			'type'    => 'url',
			'default' => ''
		);

		// Footer Text
		$section = $prefix . 'footer-text-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Footer Text', 'smartzine' ),
			'priority'    => 120,
			'panel'       => $general_panel,
		);
		$options[$prefix . 'footer-text'] = array(
			'id'           => $prefix . 'footer-text',
			'label'        => '',
			'description'  => __( 'Customize the footer text.', 'smartzine' ),
			'section'      => $section,
			'type'         => 'textarea',
			'default'      => '&copy; ' . date( 'Y' ) . ' <a href="' . esc_url( home_url() ) . '">' . esc_attr( get_bloginfo( 'name' ) ) . '</a> &middot; <span class="themejunkie">' . sprintf( __( 'Designed by %s', 'smartzine' ), '<a href="http://www.theme-junkie.com/">Theme Junkie</a>' ) . '</span>'
		);

	// Header Panels and Sections
	$header_panel = 'header';

	$panels[] = array(
		'id'       => $header_panel,
		'title'    => __( 'Header', 'smartzine' ),
		'priority' => 15
	);

		// Logo
		$section = $prefix . 'logo-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Logo', 'smartzine' ),
			'priority'    => 30,
			'panel'       => $header_panel
		);
		$options[$prefix . 'logo'] = array(
			'id'      => $prefix . 'logo',
			'label'   => __( 'Regular Logo', 'smartzine' ),
			'section' => $section,
			'type'    => 'image',
			'default' => ''
		);
		$options[$prefix . 'retina-logo'] = array(
			'id'           => $prefix . 'retina-logo',
			'label'        => __( 'Retina Logo', 'smartzine' ),
			'description'  => __( 'The Retina Logo should be twice the size of the Regular Logo.', 'smartzine' ),
			'section'      => $section,
			'type'         => 'image',
			'default'      => '',
		);

	// Home Panel and Sections
	$content_panel = 'home';

	$panels[] = array(
		'id'       => $content_panel,
		'title'    => __( 'Home', 'smartzine' ),
		'priority' => 17
	);

		// Home Featured
		$section = $prefix . 'home-featured-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Featured', 'smartzine' ),
			'description' => __( 'Featured Area.', 'smartzine' ),
			'priority'    => 5,
			'panel'       => $content_panel
		);
		$options[$prefix . 'home-featured-enable'] = array(
			'id'          => $prefix . 'home-featured-enable',
			'label'       => __( 'Show featured posts', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'home-featured-layout'] = array(
			'id'          => $prefix . 'home-featured-layout',
			'label'       => __( 'Select layout', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'boxes',
			'choices'     => array(
				'boxes'  => __( 'Boxes', 'smartzine' ),
				'slider' => __( 'Slider', 'smartzine' )
			)
		);
		$options[$prefix . 'home-featured-tag'] = array(
			'id'          => $prefix . 'home-featured-tag',
			'label'       => __( 'Select a tag', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => smartzine_tags_list()
		);
		$options[$prefix . 'home-featured-num'] = array(
			'id'          => $prefix . 'home-featured-num',
			'label'       => __( 'Number of posts (Slider layout only)', 'smartzine' ),
			'section'     => $section,
			'type'        => 'text',
			'default'     => 6
		);
		$options[$prefix . 'home-featured-orderby'] = array(
			'id'          => $prefix . 'home-featured-orderby',
			'label'       => __( 'Order by', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'date',
			'choices'     => array(
				'date'  => __( 'Date', 'smartzine' ),
				'rand'  => __( 'Random', 'smartzine' )
			)
		);

		// Home Widgets
		$section = $prefix . 'home-widget-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Widget', 'smartzine' ),
			'description' => __( 'Select widget area. Default is \'home\'.', 'smartzine' ),
			'priority'    => 5,
			'panel'       => $content_panel
		);
		$options[$prefix . 'home-widget'] = array(
			'id'          => $prefix . 'home-widget',
			'label'       => __( 'Select widget area', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select2',
			'default'     => 'home',
			'choices'     => smartzine_sidebars_list()
		);
		
	// Colors Panel and Sections
	$color_panel = 'color';

	$panels[] = array(
		'id'       => $color_panel,
		'title'    => __( 'Color', 'smartzine' ),
		'priority' => 20
	);
		
		// Header background color
		$section = $prefix . 'header-bg-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Header', 'smartzine' ),
			'priority'    => 5,
			'panel'       => $color_panel
		);
		$options[$prefix . 'header-color'] = array(
			'id'          => $prefix . 'header-color',
			'label'       => __( 'Background color', 'smartzine' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#fff',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'site-title-color'] = array(
			'id'          => $prefix . 'site-title-color',
			'label'       => __( 'Site Title', 'smartzine' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#000',
			'transport'   => 'postMessage'
		);

		// Menu background color
		$section = $prefix . 'menu-bg-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Menu', 'smartzine' ),
			'priority'    => 15,
			'panel'       => $color_panel
		);
		$options[$prefix . 'menu-color'] = array(
			'id'          => $prefix . 'menu-color',
			'label'       => __( 'Background color', 'smartzine' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#141414',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'menu-link-color'] = array(
			'id'          => $prefix . 'menu-link-color',
			'label'       => __( 'Link color', 'smartzine' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#ffffff',
			'transport'   => 'postMessage'
		);

		// Content colors
		$section = $prefix . 'content-bg-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Content', 'smartzine' ),
			'priority'    => 20,
			'panel'       => $color_panel
		);
		$options[$prefix . 'content-color'] = array(
			'id'          => $prefix . 'content-color',
			'label'       => __( 'Background color', 'smartzine' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#ffffff',
			'transport'   => 'postMessage'
		);
		/* $options[$prefix . 'content-border-color'] = array(
			'id'          => $prefix . 'content-border-color',
			'label'       => __( 'Border color', 'smartzine' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#e9e9e9',
			'transport'   => 'postMessage'
		); */
		$options[$prefix . 'content-text-color'] = array(
			'id'          => $prefix . 'content-text-color',
			'label'       => __( 'Text color', 'smartzine' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#777777',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'content-heading-color'] = array(
			'id'          => $prefix . 'content-heading-color',
			'label'       => __( 'Heading color', 'smartzine' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#323232',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'content-link-color'] = array(
			'id'          => $prefix . 'content-link-color',
			'label'       => __( 'Link color', 'smartzine' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#ff4020',
			'transport'   => 'postMessage'
		);
		$options[$prefix . 'content-link-hover-color'] = array(
			'id'          => $prefix . 'content-link-hover-color',
			'label'       => __( 'Link hover color', 'smartzine' ),
			'section'     => $section,
			'type'        => 'color',
			'default'     => '#ff6c53',
			'transport'   => 'postMessage'
		);

	// Background Image Panels and Sections
	$bgimage_panel = 'bg_image';

	$panels[] = array(
		'id'       => $bgimage_panel,
		'title'    => __( 'Background Image', 'smartzine' ),
		'priority' => 25
	);

	// Typography Panel and Sections
	$typo_panel = 'typography';

	$panels[] = array(
		'id'       => $typo_panel,
		'title'    => __( 'Typography', 'smartzine' ),
		'priority' => 30
	);

		// Global typography
		$section = $prefix . 'global-typography';
		$font_choices = customizer_library_get_font_choices();

		$sections[] = array(
			'id'       => $section,
			'title'    => __( 'Global', 'smartzine' ),
			'priority' => 5,
			'panel'    => $typo_panel
		);
		$options[$prefix . 'text-font'] = array(
			'id'          => $prefix . 'text-font',
			'label'       => __( 'Text font', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Open Sans',
		);
		$options[$prefix . 'heading-font'] = array(
			'id'          => $prefix . 'heading-font',
			'label'       => __( 'Heading font', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => $font_choices,
			'default'     => 'Serif',
		);

	// Content Panel and Sections
	$content_panel = 'content-layout';

	$panels[] = array(
		'id'       => $content_panel,
		'title'    => __( 'Content Layout', 'smartzine' ),
		'priority' => 35
	);

		// Featured posts
		$section = $prefix . 'featured-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Featured Posts', 'smartzine' ),
			'description' => __( 'Featured posts.', 'smartzine' ),
			'priority'    => 5,
			'panel'       => $content_panel
		);
		$options[$prefix . 'featured-enable'] = array(
			'id'          => $prefix . 'featured-enable',
			'label'       => __( 'Show featured posts', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'featured-title'] = array(
			'id'          => $prefix . 'featured-title',
			'label'       => __( 'Featured title', 'smartzine' ),
			'section'     => $section,
			'type'        => 'text',
			'default'     => __( 'Featured News', 'smartzine' )
		);
		$options[$prefix . 'featured-tag'] = array(
			'id'          => $prefix . 'featured-tag',
			'label'       => __( 'Select a tag', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select2',
			'choices'     => smartzine_tags_list()
		);
		$options[$prefix . 'featured-num'] = array(
			'id'          => $prefix . 'featured-num',
			'label'       => __( 'Number of posts', 'smartzine' ),
			'section'     => $section,
			'type'        => 'text',
			'default'     => 3
		);
		$options[$prefix . 'featured-orderby'] = array(
			'id'          => $prefix . 'featured-orderby',
			'label'       => __( 'Order by', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'date',
			'choices'     => array(
				'date'  => __( 'Date', 'smartzine' ),
				'rand'  => __( 'Random', 'smartzine' )
			)
		);

		// Posts
		$section = $prefix . 'posts-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Posts', 'smartzine' ),
			'description' => __( 'Posts is a single post page.', 'smartzine' ),
			'priority'    => 10,
			'panel'       => $content_panel
		);
		$options[$prefix . 'post-meta-group'] = array(
			'id'          => $prefix . 'post-meta-group',
			'label'       => __( 'Post Meta', 'smartzine' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'post-thumbnail'] = array(
				'id'          => $prefix . 'post-thumbnail',
				'label'       => __( 'Show post thumbnail', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'post-author'] = array(
				'id'          => $prefix . 'post-author',
				'label'       => __( 'Show post author name', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'post-author-twitter'] = array(
				'id'          => $prefix . 'post-author-twitter',
				'label'       => __( 'Show post author Twitter', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'post-date'] = array(
				'id'          => $prefix . 'post-date',
				'label'       => __( 'Show post date', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'post-share'] = array(
				'id'          => $prefix . 'post-share',
				'label'       => __( 'Show post share', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'post-author-box'] = array(
				'id'          => $prefix . 'post-author-box',
				'label'       => __( 'Show post author box', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'post-nav'] = array(
				'id'          => $prefix . 'post-nav',
				'label'       => __( 'Show post navigation', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
		$options[$prefix . 'post-date-group'] = array(
			'id'          => $prefix . 'post-date-group',
			'label'       => __( 'Post Date', 'smartzine' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'post-date-style'] = array(
				'id'          => $prefix . 'post-date-style',
				'label'       => __( 'Style', 'smartzine' ),
				'section'     => $section,
				'type'        => 'select',
				'default'     => 'absolute',
				'choices'     => array(
					'absolute' => __( 'Absolute (June 20, 2015 10:19 am)', 'smartzine' ),
					'relative' => __( 'Relative (1 week ago)', 'smartzine' )
				)
			);
		$options[$prefix . 'post-footer-group'] = array(
			'id'          => $prefix . 'post-footer-group',
			'label'       => __( 'Category and Tag', 'smartzine' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'post-cat'] = array(
				'id'          => $prefix . 'post-cat',
				'label'       => __( 'Show post categories', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'post-tag'] = array(
				'id'          => $prefix . 'post-tag',
				'label'       => __( 'Show post tags', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
		$options[$prefix . 'related-posts-group'] = array(
			'id'          => $prefix . 'related-posts-group',
			'label'       => __( 'Related Posts', 'smartzine' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'related-posts'] = array(
				'id'          => $prefix . 'related-posts',
				'label'       => __( 'Show related posts', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'related-posts-title'] = array(
				'id'          => $prefix . 'related-posts-title',
				'label'       => __( 'Related posts title', 'smartzine' ),
				'section'     => $section,
				'type'        => 'text',
				'default'     => __( 'You might also like', 'smartzine' )
			);
			$options[$prefix . 'related-posts-img'] = array(
				'id'          => $prefix . 'related-posts-img',
				'label'       => __( 'Show related posts thumbnail', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'related-posts-cat'] = array(
				'id'          => $prefix . 'related-posts-cat',
				'label'       => __( 'Show related posts category', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 1
			);
			$options[$prefix . 'related-posts-excerpt'] = array(
				'id'          => $prefix . 'related-posts-excerpt',
				'label'       => __( 'Show related posts excerpt', 'smartzine' ),
				'section'     => $section,
				'type'        => 'switch',
				'default'     => 0
			);

		// Page
		$section = $prefix . 'page-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Page', 'smartzine' ),
			'priority'    => 15,
			'panel'       => $content_panel
		);
		$options[$prefix . 'page-title'] = array(
			'id'          => $prefix . 'page-title',
			'label'       => __( 'Show page title', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Archive
		$section = $prefix . 'archive-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Archive', 'smartzine' ),
			'description' => __( 'Blog, date, month and year page.', 'smartzine' ),
			'priority'    => 20,
			'panel'       => $content_panel
		);
		$options[$prefix . 'archive-layout'] = array(
			'id'          => $prefix . 'archive-layout',
			'label'       => __( 'Select layout', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'standard',
			'choices'     => array(
				'standard' => __( 'Standard', 'smartzine' ),
				'list'     => __( 'List', 'smartzine' ),
				'grid'     => __( 'Grid', 'smartzine' ),
			)
		);
		$options[$prefix . 'archive-thumbnail'] = array(
			'id'          => $prefix . 'archive-thumbnail',
			'label'       => __( 'Show thumbnail', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'archive-category'] = array(
			'id'          => $prefix . 'archive-category',
			'label'       => __( 'Show category', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'archive-excerpt'] = array(
			'id'          => $prefix . 'archive-excerpt',
			'label'       => __( 'Show excerpt', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'archive-excerpt-limit'] = array(
			'id'          => $prefix . 'archive-excerpt-limit',
			'label'       => __( 'Excerpt limit', 'smartzine' ),
			'section'     => $section,
			'type'        => 'number',
			'default'     => 15
		);
		$options[$prefix . 'archive-meta'] = array(
			'id'          => $prefix . 'archive-meta',
			'label'       => __( 'Show post meta', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'archive-review'] = array(
			'id'          => $prefix . 'archive-review',
			'label'       => __( 'Show review', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Author page
		$section = $prefix . 'author-layout-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Author', 'smartzine' ),
			'description' => __( 'Please navigate the preview to the author page to see the changes.', 'smartzine' ),
			'priority'    => 25,
			'panel'       => $content_panel
		);
		$options[$prefix . 'author-layout'] = array(
			'id'          => $prefix . 'author-layout',
			'label'       => __( 'Select layout', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'standard',
			'choices'     => array(
				'standard' => __( 'Standard', 'smartzine' ),
				'list'     => __( 'List', 'smartzine' ),
				'grid'     => __( 'Grid', 'smartzine' ),
			)
		);
		$options[$prefix . 'author-thumbnail'] = array(
			'id'          => $prefix . 'author-thumbnail',
			'label'       => __( 'Show thumbnail', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'author-category'] = array(
			'id'          => $prefix . 'author-category',
			'label'       => __( 'Show category', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'author-excerpt'] = array(
			'id'          => $prefix . 'author-excerpt',
			'label'       => __( 'Show excerpt', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'author-excerpt-limit'] = array(
			'id'          => $prefix . 'author-excerpt-limit',
			'label'       => __( 'Excerpt limit', 'smartzine' ),
			'section'     => $section,
			'type'        => 'number',
			'default'     => 15
		);
		$options[$prefix . 'author-meta'] = array(
			'id'          => $prefix . 'author-meta',
			'label'       => __( 'Show post meta', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'author-review'] = array(
			'id'          => $prefix . 'author-review',
			'label'       => __( 'Show review', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Category
		$section = $prefix . 'category-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Category', 'smartzine' ),
			'description' => __( 'Please navigate the preview to the category page to see the changes.', 'smartzine' ),
			'priority'    => 30,
			'panel'       => $content_panel
		);
		$options[$prefix . 'cat-layout'] = array(
			'id'          => $prefix . 'cat-layout',
			'label'       => __( 'Select layout', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'standard',
			'choices'     => array(
				'standard' => __( 'Standard', 'smartzine' ),
				'list'     => __( 'List', 'smartzine' ),
				'grid'     => __( 'Grid', 'smartzine' ),
			)
		);
		$options[$prefix . 'cat-thumbnail'] = array(
			'id'          => $prefix . 'cat-thumbnail',
			'label'       => __( 'Show thumbnail', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'cat-category'] = array(
			'id'          => $prefix . 'cat-category',
			'label'       => __( 'Show category', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'cat-excerpt'] = array(
			'id'          => $prefix . 'cat-excerpt',
			'label'       => __( 'Show excerpt', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'cat-excerpt-limit'] = array(
			'id'          => $prefix . 'cat-excerpt-limit',
			'label'       => __( 'Excerpt limit', 'smartzine' ),
			'section'     => $section,
			'type'        => 'number',
			'default'     => 15
		);
		$options[$prefix . 'cat-meta'] = array(
			'id'          => $prefix . 'cat-meta',
			'label'       => __( 'Show post meta', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'cat-review'] = array(
			'id'          => $prefix . 'cat-review',
			'label'       => __( 'Show review', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Tag page
		$section = $prefix . 'tag-layout-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Tag', 'smartzine' ),
			'description' => __( 'Please navigate the preview to the tag page to see the changes.', 'smartzine' ),
			'priority'    => 35,
			'panel'       => $content_panel
		);
		$options[$prefix . 'tag-layout'] = array(
			'id'          => $prefix . 'tag-layout',
			'label'       => __( 'Select layout', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'standard',
			'choices'     => array(
				'standard' => __( 'Standard', 'smartzine' ),
				'list'     => __( 'List', 'smartzine' ),
				'grid'     => __( 'Grid', 'smartzine' ),
			)
		);
		$options[$prefix . 'tag-thumbnail'] = array(
			'id'          => $prefix . 'tag-thumbnail',
			'label'       => __( 'Show thumbnail', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'tag-category'] = array(
			'id'          => $prefix . 'tag-category',
			'label'       => __( 'Show category', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'tag-excerpt'] = array(
			'id'          => $prefix . 'tag-excerpt',
			'label'       => __( 'Show excerpt', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'tag-excerpt-limit'] = array(
			'id'          => $prefix . 'tag-excerpt-limit',
			'label'       => __( 'Excerpt limit', 'smartzine' ),
			'section'     => $section,
			'type'        => 'number',
			'default'     => 15
		);
		$options[$prefix . 'tag-meta'] = array(
			'id'          => $prefix . 'tag-meta',
			'label'       => __( 'Show post meta', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'tag-review'] = array(
			'id'          => $prefix . 'tag-review',
			'label'       => __( 'Show review', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

		// Search page
		$section = $prefix . 'search-layout-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Search', 'smartzine' ),
			'description' => __( 'Please navigate the preview to the search page to see the changes.', 'smartzine' ),
			'priority'    => 40,
			'panel'       => $content_panel
		);
		$options[$prefix . 'search-layout'] = array(
			'id'          => $prefix . 'search-layout',
			'label'       => __( 'Select layout', 'smartzine' ),
			'section'     => $section,
			'type'        => 'select',
			'default'     => 'standard',
			'choices'     => array(
				'standard' => __( 'Standard', 'smartzine' ),
				'list'     => __( 'List', 'smartzine' ),
				'grid'     => __( 'Grid', 'smartzine' ),
			)
		);
		$options[$prefix . 'search-thumbnail'] = array(
			'id'          => $prefix . 'search-thumbnail',
			'label'       => __( 'Show thumbnail', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'search-category'] = array(
			'id'          => $prefix . 'search-category',
			'label'       => __( 'Show category', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'search-excerpt'] = array(
			'id'          => $prefix . 'search-excerpt',
			'label'       => __( 'Show excerpt', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'search-excerpt-limit'] = array(
			'id'          => $prefix . 'search-excerpt-limit',
			'label'       => __( 'Excerpt limit', 'smartzine' ),
			'section'     => $section,
			'type'        => 'number',
			'default'     => 15
		);
		$options[$prefix . 'search-meta'] = array(
			'id'          => $prefix . 'search-meta',
			'label'       => __( 'Show post meta', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);
		$options[$prefix . 'search-review'] = array(
			'id'          => $prefix . 'search-review',
			'label'       => __( 'Show review', 'smartzine' ),
			'section'     => $section,
			'type'        => 'switch',
			'default'     => 1
		);

	// Advertisement Panel and Sections
	$ads_panel = 'advertisement';

	$panels[] = array(
		'id'       => $ads_panel,
		'title'    => __( 'Advertisement', 'smartzine' ),
		'priority' => 45
	);

		// Header ads
		$section = $prefix . 'header-ads-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Header', 'smartzine' ),
			'priority'    => 5,
			'panel'       => $ads_panel,
		);
		$options[$prefix . 'header-ads-image'] = array(
			'id'           => $prefix . 'header-ads-image',
			'label'        => __( 'Ads Image', 'smartzine' ),
			'description'  => __( 'Upload your ads image then put the url in the setting below.', 'smartzine' ),
			'section'      => $section,
			'type'         => 'image',
			'default'      => '',
		);
		$options[$prefix . 'header-ads-url'] = array(
			'id'           => $prefix . 'header-ads-url',
			'label'        => __( 'Ads URL', 'smartzine' ),
			'description'  => __( 'Put the ads url in the box below.', 'smartzine' ),
			'section'      => $section,
			'type'         => 'url',
			'default'      => ''
		);
		$options[$prefix . 'header-ads-custom'] = array(
			'id'                => $prefix . 'header-ads-custom',
			'label'             => __( 'Or', 'smartzine' ),
			'description'       => __( 'Pur you custom ads code (eg. adsense) in the box below.', 'smartzine' ),
			'section'           => $section,
			'type'              => 'textarea',
			'sanitize_callback' => 'smartzine_textarea_stripslashes',
			'default'           => ''
		);

		// Posts ads
		$section = $prefix . 'posts-ads-section';

		$sections[] = array(
			'id'          => $section,
			'title'       => __( 'Posts', 'smartzine' ),
			'description' => __( 'Single post advertisement', 'smartzine' ),
			'priority'    => 10,
			'panel'       => $ads_panel,
		);
		$options[$prefix . 'post-ads-before'] = array(
			'id'          => $prefix . 'post-ads-before',
			'label'       => __( 'Ads Before Content', 'smartzine' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'post-ads-image-before'] = array(
				'id'           => $prefix . 'post-ads-image-before',
				'label'        => __( 'Ads Image', 'smartzine' ),
				'description'  => __( 'Upload your ads image then put the url in the setting below.', 'smartzine' ),
				'section'      => $section,
				'type'         => 'image',
				'default'      => '',
			);
			$options[$prefix . 'post-ads-url-before'] = array(
				'id'           => $prefix . 'post-ads-url-before',
				'label'        => __( 'Ads URL', 'smartzine' ),
				'description'  => __( 'Put the ads url in the box below.', 'smartzine' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);
			$options[$prefix . 'post-ads-custom-before'] = array(
				'id'                => $prefix . 'post-ads-custom-before',
				'label'             => __( 'Or', 'smartzine' ),
				'description'       => __( 'Pur you custom ads code (eg. adsense) in the box below.', 'smartzine' ),
				'section'           => $section,
				'type'              => 'textarea',
				'sanitize_callback' => 'smartzine_textarea_stripslashes',
				'default'           => ''
			);
		$options[$prefix . 'post-ads-after'] = array(
			'id'          => $prefix . 'post-ads-after',
			'label'       => __( 'Ads After Content', 'smartzine' ),
			'section'     => $section,
			'type'        => 'group-title'
		);
			$options[$prefix . 'post-ads-image-after'] = array(
				'id'           => $prefix . 'post-ads-image-after',
				'label'        => __( 'Ads Image', 'smartzine' ),
				'description'  => __( 'Upload your ads image then put the url in the setting below.', 'smartzine' ),
				'section'      => $section,
				'type'         => 'image',
				'default'      => '',
			);
			$options[$prefix . 'post-ads-url-after'] = array(
				'id'           => $prefix . 'post-ads-url-after',
				'label'        => __( 'Ads URL', 'smartzine' ),
				'description'  => __( 'Put the ads url in the box below.', 'smartzine' ),
				'section'      => $section,
				'type'         => 'url',
				'default'      => ''
			);
			$options[$prefix . 'post-ads-custom-after'] = array(
				'id'                => $prefix . 'post-ads-custom-after',
				'label'             => __( 'Or', 'smartzine' ),
				'description'       => __( 'Pur you custom ads code (eg. adsense) in the box below.', 'smartzine' ),
				'section'           => $section,
				'type'              => 'textarea',
				'sanitize_callback' => 'smartzine_textarea_stripslashes',
				'default'           => ''
			);

	// Adds the sections to the $options array
	$options['sections'] = $sections;

	// Adds the panels to the $options array
	$options['panels'] = $panels;

	$customizer_library = Customizer_Library::Instance();
	$customizer_library->add_options( $options );

}
add_action( 'init', 'smartzine_customizer_register' );