<?php
/**
 * Custom function to display data set in customizer.
 *
 * @package    SmartZine
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Loads custom style set in customizer
 */
require trailingslashit( get_template_directory() ) . 'inc/styles/header.php';
require trailingslashit( get_template_directory() ) . 'inc/styles/menu.php';
require trailingslashit( get_template_directory() ) . 'inc/styles/content.php';
require trailingslashit( get_template_directory() ) . 'inc/styles/fonts.php';

if ( ! function_exists( 'smartzine_customizer_styles' ) ) :
/**
 * Generates the style tag and CSS needed for the theme options.
 *
 * By using the "Customizer_Library_Styles" filter, different components can print CSS in the header.
 * It is organized this way to ensure there is only one "style" tag.
 *
 * @since  1.0.0
 */
function smartzine_customizer_styles() {

	// Action to add the custom styles.
	do_action( 'smartzine_customizer_library_styles' );

	// Echo the rules
	$css = Customizer_Library_Styles()->build();

	if ( ! empty( $css ) ) {
		echo "\n<!-- Begin Custom CSS -->\n<style type=\"text/css\" id=\"custom-css\">\n";
		echo $css;
		echo "\n</style>\n<!-- End Custom CSS -->\n";
	}

}
endif;
add_action( 'wp_head', 'smartzine_customizer_styles', 11 );

if ( ! function_exists( 'smartzine_display_favicon' ) ) :
/**
 * Display the favicon
 *
 * @since 1.0.0
 */
function smartzine_display_favicon() {
	
	// Theme prefix
	$prefix = 'smartzine-';

	// Get the favicon
	$favicon = smartzine_mod( $prefix . 'favicon' );

	if ( $favicon ) {
		echo '<link href="' . esc_url( $favicon ) . '" rel="shortcut icon">' . "\n";
	}

}
endif;
add_action( 'wp_head', 'smartzine_display_favicon', 5 );

if ( ! function_exists( 'smartzine_display_mobile_icon' ) ) :
/**
 * Display the mobile icon
 *
 * @since 1.0.0
 */
function smartzine_display_mobile_icon() {
	
	// Theme prefix
	$prefix = 'smartzine-';

	// Get the mobile icon
	$icon = smartzine_mod( $prefix . 'mobile-icon' );

	if ( $icon ) {
		echo '<link href="' . esc_url( $icon ) . '" rel="apple-touch-icon-precomposed">' . "\n";
	}

}
endif;
add_action( 'wp_head', 'smartzine_display_mobile_icon', 6 );

if ( ! function_exists( 'smartzine_custom_feed_url' ) ) :
/**
 * Custom RSS feed url.
 *
 * @since  1.0.0
 */
function smartzine_custom_feed_url( $output, $feed ) {

	// Theme prefix
	$prefix = 'smartzine-';

	// Get the custom rss feed url
	$url = smartzine_mod( $prefix . 'custom-rss' );

	// Do not redirect comments feed
	if ( strpos( $output, 'comments' ) ) {
		return $output;
	}

	// Check the settings.
	if ( ! empty( $url ) ) {
		$output = esc_url( $url );
	}

	return $output;
}
endif;
add_filter( 'feed_link', 'smartzine_custom_feed_url', 10, 2 );

if ( ! function_exists( 'smartzine_post_ads_before' ) ) :
/**
 * Single post advertisement.
 * Before content.
 *
 * @since  1.0.0
 */
function smartzine_post_ads_before( $content ) {

	// Theme prefix
	$prefix = 'smartzine-';

	// Set up empty variable
	$ads = '';

	// Get the ads data set in customizer
	$img    = smartzine_mod( $prefix . 'post-ads-image-before' );
	$url    = smartzine_mod( $prefix . 'post-ads-url-before' );
	$custom = smartzine_mod( $prefix . 'post-ads-custom-before' );

	// Set up our ads.
	if ( $img || $url || $custom ) {
		$ads = '<div class="post-ads-before post-ads" style="margin-bottom: 20px;">';
			if ( $custom ) {
				$ads .= stripslashes( $custom );
			} else {
				$ads .= '<a href="' . esc_url( $url ) . '"><img src="' . esc_url( $img ) . '" /></a>';
			}
		$ads .= '</div>';
	}

	// Display the ads before content
	if ( ! empty( $ads ) && is_single() ) {
		$content = $ads . $content;
	} else {
		$content;
	}

	return $content;

}
endif;
add_filter( 'the_content', 'smartzine_post_ads_before', 20 );

if ( ! function_exists( 'smartzine_post_ads_after' ) ) :
/**
 * Single post advertisement.
 * After content.
 *
 * @since  1.0.0
 */
function smartzine_post_ads_after( $content ) {

	// Theme prefix
	$prefix = 'smartzine-';

	// Set up empty variable
	$ads = '';

	// Get the ads data set in customizer
	$img    = smartzine_mod( $prefix . 'post-ads-image-after' );
	$url    = smartzine_mod( $prefix . 'post-ads-url-after' );
	$custom = smartzine_mod( $prefix . 'post-ads-custom-after' );

	// Set up our ads.
	if ( $img || $url || $custom ) {
		$ads = '<div class="post-ads-after post-ads" style="margin-top: 20px;">';
			if ( $custom ) {
				$ads .= stripslashes( $custom );
			} else {
				$ads .= '<a href="' . esc_url( $url ) . '"><img src="' . esc_url( $img ) . '" /></a>';
			}
		$ads .= '</div>';
	}

	// Display the ads before content
	if ( ! empty( $ads ) && is_single() ) {
		$content = $content . $ads;
	} else {
		$content;
	}

	return $content;

}
endif;
add_filter( 'the_content', 'smartzine_post_ads_after', 20 );