<?php
/**
 * Custom template tags for this theme.
 * Eventually, some of the functionality here could be replaced by core features.
 * 
 * @package    SmartZine
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

if ( ! function_exists( 'smartzine_site_branding' ) ) :
/**
 * Site branding for the site.
 * 
 * Display site title by default, but user can change it with their custom logo.
 * They can upload it on Customizer page.
 * 
 * @since  1.0.0
 */
function smartzine_site_branding() {

	// Get the customizer value.
	$prefix = 'smartzine-';
	$logo   = smartzine_mod( $prefix . 'logo' );

	// Check if logo available, then display it.
	if ( $logo ) :
		echo '<div id="logo" itemscope itemtype="http://schema.org/Brand">' . "\n";
			echo '<a href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home">' . "\n";
				echo '<img itemprop="logo" src="' . esc_url( $logo ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" />' . "\n";
			echo '</a>' . "\n";
		echo '</div>' . "\n";

	// If not, then display the Site Title and Site Description.
	else :
		echo '<div id="logo">'. "\n";
			echo '<h1 class="site-title" ' . hybrid_get_attr( 'site-title' ) . '><a href="' . esc_url( get_home_url() ) . '" itemprop="url" rel="home"><span itemprop="headline">' . esc_attr( get_bloginfo( 'name' ) ) . '</span></a></h1>'. "\n";
			echo '<p class="site-desc" ' . hybrid_get_attr( 'site-description' ) . '>' . esc_attr( get_bloginfo( 'description' ) ) . '</h2>';
		echo '</div>'. "\n";
	endif;

}
endif;

if ( ! function_exists( 'smartzine_footer_text' ) ) :
/**
 * Footer Text
 */
function smartzine_footer_text() {

	// Theme prefix
	$prefix = 'smartzine-';

	// Get the customizer data 
	$footer_text = smartzine_mod( $prefix . 'footer-text' );

	// Display the data
	echo '<div class="copyright">' . stripslashes( $footer_text ) . '</div>';
	
}
endif;

if ( ! function_exists( 'smartzine_social_icons' ) ) :
/**
 * Header social
 */
function smartzine_social_icons( $position='header' ) {

	// Theme prefix
	$prefix = 'smartzine-';

	// Get the customizer data 
	$tw        = smartzine_mod( $prefix . 'twitter' );
	$fb        = smartzine_mod( $prefix . 'facebook' );
	$gplus     = smartzine_mod( $prefix . 'gplus' );
	$instagram = smartzine_mod( $prefix . 'instagram' );
	$pinterest = smartzine_mod( $prefix . 'pinterest' );
	$tumblr    = smartzine_mod( $prefix . 'tumblr' );
	$rss       = smartzine_mod( $prefix . 'rss' );

	// Display the data
	if ( $tw || $fb || $gplus || $instagram || $pinterest || $tumblr || $rss ) {
		echo '<div id="' . $position . '-social" class="social-icons">';
			if ( $tw ) {
				echo '<a href="' . esc_url( $tw ) . '"><i class="fa fa-twitter"></i></a> ';
			}
			if ( $fb ) {
				echo '<a href="' . esc_url( $fb ) . '"><i class="fa fa-facebook"></i></a> ';
			}
			if ( $gplus ) {
				echo '<a href="' . esc_url( $gplus ) . '"><i class="fa fa-google-plus"></i></a> ';
			}
			if ( $instagram ) {
				echo '<a href="' . esc_url( $instagram ) . '"><i class="fa fa-instagram"></i></a> ';
			}
			if ( $pinterest ) {
				echo '<a href="' . esc_url( $pinterest ) . '"><i class="fa fa-pinterest"></i></a> ';
			}
			if ( $tumblr ) {
				echo '<a href="' . esc_url( $rss ) . '"><i class="fa fa-tumblr"></i></a> ';
			}
			if ( $rss ) {
				echo '<a href="' . esc_url( $rss ) . '"><i class="fa fa-rss"></i></a>';
			}
		echo '</div>';
	}
	
}
endif;

if ( ! function_exists( 'smartzine_header_ads' ) ) :
/**
 * Prints the advertisement data set in customizer.
 * 
 * @since  1.0.0
 */
function smartzine_header_ads() {

	// Theme prefix
	$prefix = 'smartzine-';

	// Get the ads data set in customizer
	$img    = smartzine_mod( $prefix . 'header-ads-image' );
	$url    = smartzine_mod( $prefix . 'header-ads-url' );
	$custom = smartzine_mod( $prefix . 'header-ads-custom' );

	// Display the data
	if ( $img || $url || $custom ) {
		echo '<div class="header-ad">';
			if ( $custom ) {
				echo stripslashes( $custom );
			} else {
				echo '<a href="' . esc_url( $url ) . '"><img src="' . esc_url( $img ) . '" /></a>';
			}
		echo '</div>';
	}

}
endif;

if ( ! function_exists( 'smartzine_featured_image' ) ) :
/**
 * Featured Image
 * 
 * @since  1.0.0
 */
function smartzine_featured_image( $args ) {

	$defaults = array(
 		'size' => 'medium',
 		'show' => true,
 		'echo' => true
	);
	
	// Parse incoming $args into an array and merge it with $defaults
	$args = wp_parse_args( $args, $defaults );
	extract( $args );

	if ( ( true == $show ) && has_post_thumbnail() ) :

		if ( true == $echo )
			the_post_thumbnail( $size, array( 'class' => 'entry-thumbnail' ) );
		else
			return get_the_post_thumbnail( get_the_ID(), $size, array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) );

	endif;
}
endif;

if ( ! function_exists( 'smartzine_single_featured_image' ) ) :
/**
 * Featured Image
 * 
 * @since  1.0.0
 */
function smartzine_single_featured_image() {

	// Theme prefix
	$prefix = 'smartzine-';

	$thumb = smartzine_mod( $prefix . 'post-thumbnail' );

	if ( true == $thumb ) :

		if ( has_post_thumbnail() ) {

			// let's try to do another trick
			// set size automatically based on sidebar/no sidebar layout

			// for has_sidebar
			$size = 'medium';

			// for no sidebar
			if ( current_theme_supports( 'theme-layouts' ) && ! is_admin() ) {
				if ( 'layout-1c' == theme_layouts_get_layout() ) {
					$size = 'large';
				}
			}
			?>
			<div class="entry-image clearfix">
				<?php the_post_thumbnail( $size ); ?>
			</div>
			<?php
		}

	endif;
}
endif;

if ( ! function_exists( 'smartzine_post_icon' ) ) :
/**
 * Post Format icons
 */
function smartzine_post_icon( $args = array() ) {

	$defaults = array(
		'layout' => 'grid',
 		'show' => true,
	);
	
	// Parse incoming $args into an array and merge it with $defaults
	$args = wp_parse_args( $args, $defaults );
	extract( $args );

	// not using this on 'Standard' layout
	if ( 'standard' == $layout )
		return;

	if ( ( true == $show ) && has_post_thumbnail() ) :

		if ( has_post_format( 'audio' ) ) {
			$icon = 'music';
		} elseif ( has_post_format( 'video' ) ) {
			$icon = 'play';
		} elseif( has_post_format( 'image' ) || has_post_format( 'gallery' ) ) {
			$icon = 'picture-o';
		} else {
			return; // bail out for other post formats
		}

	?>
		<span class="post-icon"><i class="fa fa-<?php echo esc_attr( $icon ); ?>"></i></span>
	<?php
	endif;
}
endif;

if ( ! function_exists( 'smartzine_post_meta' ) ) :
/**
 * Prints HTML with meta information:
 * - post-date/time 
 * - comment counts
 * - author
 * - edit links
 *
 * @since 1.0.0
 */
function smartzine_post_meta( $args ) {

	// Hide Post Meta for pages on Search
	if ( 'post' != get_post_type() ) 
		return;

	$defaults = array(
 		'show' => true
	);
	
	// Parse incoming $args into an array and merge it with $defaults
	$args = wp_parse_args( $args, $defaults );
	extract( $args );

	if ( true == $show ) :
	?>
		<div class="entry-meta">
			<?php				
			$time_string = '<time class="entry-date published" datetime="%1$s" ' . hybrid_get_attr( 'entry-published' ) . '>%2$s</time>';

			$time_string = sprintf( $time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() )
			);

			// posted on
			printf( __( '<span class="date"><i class="fa fa-clock-o"></i> %1$s</span>', 'smartzine' ), $time_string );

			// comments count
			smartzine_comment_count();

			// post author
			smartzine_post_author( false );

			// edit link
			edit_post_link( __( 'Edit', 'smartzine' ), '<span class="edit-link"><i class="fa fa-pencil-square-o"></i> ', '</span>' );
			?>
		</div>
		<?php
	endif;
}
endif;

if ( ! function_exists( 'smartzine_post_author' ) ) :
/**
 * Post Author
 */
function smartzine_post_author( $show_twitter=true ) {

	// Theme prefix
	$prefix = 'smartzine-';

	// Get the data set in customizer
	$author  = smartzine_mod( $prefix . 'post-author' );
	$twitter = ( $show_twitter ) ? smartzine_mod( $prefix . 'post-author-twitter' ) : false;

	// Get the twitter username.
	$tw = get_the_author_meta( 'tw_username' );

	if ( $author ) : ?>
		<span class="author" <?php hybrid_attr( 'entry-author' ) ?>><i class="fa fa-user"></i> <?php printf( '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '" itemprop="url"><span class="author-name" itemprop="name">' . esc_html( get_the_author() ) . '</span></a>' ); ?></span>
	<?php endif; ?>

	<?php if ( $twitter && $tw ) : ?>
		<span class="author-twitter"><a href="https://twitter.com/<?php echo esc_attr( $tw ) ?>" title="<?php esc_attr_e( 'Follow on Twitter', 'smartzine' ); ?>"><i class="fa fa-twitter"></i> @<?php echo esc_attr( $tw ); ?></a></span>
	<?php endif;

}
endif;

if ( ! function_exists( 'smartzine_posted_on' ) ) :
/**
 * Post Author
 */
function smartzine_posted_on() {

	// Theme prefix
	$prefix = 'smartzine-';

	// Get the data set in customizer
	$date       = smartzine_mod( $prefix . 'post-date' );
	$date_style = smartzine_mod( $prefix . 'post-date-style' );

	if ( $date ) :
	?>
		<span class="date">
			<i class="fa fa-clock-o"></i>
			<time class="published" datetime="<?php echo esc_html( get_the_date( 'c' ) ); ?>" <?php hybrid_attr( 'entry-published' ) ?>>
				<?php 
				if ( $date_style == 'absolute' ) {
					echo esc_html( get_the_date() );
				} else {
					printf( __( '%s ago', 'smartzine' ), human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) );
				}
				?>
			</time>
		</span>
	<?php
	endif;

}
endif;

if ( ! function_exists( 'smartzine_comment_count' ) ) :
/**
 * Comment count
 *
 * @since  1.0.0
 */
function smartzine_comment_count() {
	?>
	<?php if ( ! post_password_required() && ( comments_open() || '0' != get_comments_number() ) ) : ?>
		<span class="comments">
			<?php comments_popup_link( __( '<i class="fa fa-comments-o"></i> 0 Comment', 'smartzine' ), __( '<i class="fa fa-comments-o"></i> 1 Comment', 'smartzine' ), __( '<i class="fa fa-comments-o"></i> % Comments', 'smartzine' ) ); ?>
		</span>
	<?php endif; ?>
	<?php
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @since  1.0.0
 * @return bool
 */
function smartzine_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'smartzine_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'smartzine_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so smartzine_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so smartzine_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in smartzine_categorized_blog.
 *
 * @since 1.0.0
 */
function smartzine_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'smartzine_categories' );
}
add_action( 'edit_category', 'smartzine_category_transient_flusher' );
add_action( 'save_post',     'smartzine_category_transient_flusher' );

if ( ! function_exists( 'smartzine_entry_category' ) ) :
/**
 * Prints HTML with Category for the current post.
 *
 * @since 1.0.0
 */
function smartzine_entry_category( $args ) {

	// Hide category text for pages on Search
	if ( 'post' != get_post_type() ) 
		return;

	$defaults = array(
 		'show' => true
	);
	
	// Parse incoming $args into an array and merge it with $defaults
	$args = wp_parse_args( $args, $defaults );
	extract( $args );

	if ( true == $show ) :

		$category = get_the_category( get_the_ID() );
		if ( $category ) :
		?>
			<div class="entry-category" <?php hybrid_attr( 'entry-terms', 'category' ); ?>>
				<a href="<?php echo esc_url( get_category_link( $category[0]->term_id ) ); ?>"><?php echo esc_attr( $category[0]->name ); ?></a>
			</div><!-- .entry-category -->
		<?php endif; // End if category ?>

	<?php endif; ?>

	<?php

}
endif;

if ( ! function_exists( 'smartzine_entry_tags' ) ) :
/**
 * Prints HTML with Tags for the current post.
 *
 * @since 1.0.0
 */
function smartzine_entry_tags() {

	// Hide tags if not in Single Post
	if ( ! is_singular( 'post' ) ) 
		return;

	// Theme prefix
	$prefix = 'smartzine-';

	// Get the data set in customizer
	$tag = smartzine_mod( $prefix . 'post-tag' );

	if ( $tag ) :

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list();
		if ( $tags_list ) :
		?>
			<div class="entry-tags" <?php hybrid_attr( 'entry-terms', 'post_tag' ); ?>>
				<?php printf( $tags_list ); ?>
			</div>
		<?php endif; // End if $tags_list ?>

	<?php endif;
}
endif;


if ( ! function_exists( 'smartzine_entry_share' ) ) :
/**
 * Social share.
 *
 * @since 1.0.0
 */
function smartzine_entry_share() {

	// Theme prefix
	$prefix = 'smartzine-';

	// Get the data set in customizer
	$share  = smartzine_mod( $prefix . 'post-share' );
	?>

	<?php if ( $share || ( function_exists( 'the_ratings' ) ) ) :
	?><div class="entry-share clearfix"><?php endif; ?>

			<?php if ( $share ) : ?>
				<ul>
					<li class="share"><?php _e( 'Share', 'smartzine' ); ?></li>
					<li class="twitter"><a href="https://twitter.com/intent/tweet?text=<?php echo esc_attr( get_the_title( get_the_ID() ) ); ?>&amp;url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-twitter"></i>Twitter</a></li>
					<li class="facebook"><a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-facebook"></i>Facebook</a></li>
					<li class="google-plus"><a href="https://plus.google.com/share?url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-google-plus"></i>Google+</a></li>
					<li class="linkedin"><a href="https://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>&amp;title=<?php echo esc_attr( get_the_title( get_the_ID() ) ); ?>" target="_blank"><i class="fa fa-linkedin"></i>LinkedIn</a></li>
					<li class="pinterest"><a href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( get_the_ID() ) ); ?>&amp;media=<?php echo urlencode( wp_get_attachment_url( get_post_thumbnail_id( get_the_ID() ) ) ); ?>" target="_blank"><i class="fa fa-pinterest"></i>Pinterest</a></li>
				</ul>
			<?php endif; ?>

			<?php if ( function_exists( 'the_ratings' ) ) { the_ratings(); } ?>

		<?php if ( $share || ( function_exists( 'the_ratings' ) ) ) :
	?></div><!-- .entry-share --> <?php endif;

}
endif;

if ( ! function_exists( 'smartzine_post_author_box' ) ) :
/**
 * Author post informations.
 *
 * @since  1.0.0
 */
function smartzine_post_author_box() {

	// Bail if not on the single post.
	if ( ! is_single() ) {
		return;
	}

	// Bail if user hasn't fill the Biographical Info field.
	if ( ! get_the_author_meta( 'description' ) ) {
		return;
	}

	// Theme prefix
	$prefix = 'smartzine-';

	// Get the data set in customizer
	$enable = smartzine_mod( $prefix . 'post-author-box' );

	// Disable if user choose it.
	if ( $enable ) :

		// Get the author social information.
		$twitter   = get_the_author_meta( 'tw_username' );
		$facebook  = get_the_author_meta( 'facebook' );
		$gplus     = get_the_author_meta( 'gplus' );
		$instagram = get_the_author_meta( 'instagram' );
		$pinterest = get_the_author_meta( 'pinterest' );

	?>
	<div class="entry-author" <?php hybrid_attr( 'entry-author' ) ?>>
		<?php echo get_avatar( is_email( get_the_author_meta( 'user_email' ) ), apply_filters( 'smartzine_author_bio_avatar_size', 100 ), '', strip_tags( get_the_author() ) ); ?>
		<div class="author-content">
			<h5 class="author-title name">
				<a class="author-name url fn n" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author" itemprop="url"><span itemprop="name"><?php echo strip_tags( get_the_author() ); ?></span></a>
			</h5>
			<p class="bio" itemprop="description"><?php echo stripslashes( get_the_author_meta( 'description' ) ); ?></p>

			<?php if ( $twitter || $facebook || $gplus || $instagram || $pinterest ) : ?>
				<div class="social-links">
					<?php if ( $twitter ) { ?>
						<a href="//twitter.com/<?php echo esc_attr( $twitter ) ?>"><i class="fa fa-twitter"></i></a>
					<?php } ?>
					<?php if ( $facebook ) { ?>
						<a href="<?php echo esc_url( $facebook ); ?>"><i class="fa fa-facebook"></i></a>
					<?php } ?>
					<?php if ( $gplus ) { ?>
						<a href="<?php echo esc_url( $gplus ); ?>"><i class="fa fa-google-plus"></i></a>
					<?php } ?>
					<?php if ( $instagram ) { ?>
						<a href="<?php echo esc_url( $instagram ); ?>"><i class="fa fa-instagram"></i></a>
					<?php } ?>
					<?php if ( $pinterest ) { ?>
						<a href="<?php echo esc_url( $pinterest ); ?>"><i class="fa fa-pinterest"></i></a>
					<?php } ?>
				</div>
			<?php endif; ?>
		</div>

	</div><!-- .author-bio -->
<?php
	endif;

}
endif;

if ( ! function_exists( 'smartzine_related_posts' ) ) :
/**
 * Related posts.
 *
 * @since  1.0.0
 */
function smartzine_related_posts() {

	// Theme prefix
	$prefix = 'smartzine-';

	// Get the data set in customizer
	$enable  = smartzine_mod( $prefix . 'related-posts' );
	$title   = smartzine_mod( $prefix . 'related-posts-title' );
	$img     = smartzine_mod( $prefix . 'related-posts-img' );
	$cat     = smartzine_mod( $prefix . 'related-posts-cat' );
	$excerpt = smartzine_mod( $prefix . 'related-posts-excerpt' );

	// Disable if user choose it.
	if ( $enable == 0 ) {
		return;
	}

	// Get the taxonomy terms of the current page for the specified taxonomy.
	$terms = wp_get_post_terms( get_the_ID(), 'category', array( 'fields' => 'ids' ) );

	// Bail if the term empty.
	if ( empty( $terms ) ) {
		return;
	}
	
	// Posts query arguments.
	$query = array(
		'post__not_in' => array( get_the_ID() ),
		'tax_query'    => array(
			array(
				'taxonomy' => 'category',
				'field'    => 'id',
				'terms'    => $terms,
				'operator' => 'IN'
			)
		),
		'posts_per_page' => 3,
		'post_type'      => 'post',
	);

	// Allow dev to filter the query.
	$args = apply_filters( 'smartzine_related_posts_args', $query );

	// The post query
	$related = new WP_Query( $args );

	if ( $related->have_posts() ) : ?>

		<div class="entry-related">
			<h3 class="block-title"><?php echo esc_attr( $title ); ?></h3>
			<ul class="clearfix">
				<?php while ( $related->have_posts() ) : $related->the_post(); ?>
					<li>
						<?php if ( has_post_thumbnail() && $img ) : ?>
							<a href="<?php the_permalink(); ?>"><?php the_post_thumbnail( 'smartzine-related', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?></a>
						<?php endif; ?>
						<?php smartzine_entry_category( array( 'show' => $cat ) ); ?>
						<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
						<?php if ( $excerpt ) : ?>
							<div class="entry-summary">
								<?php echo apply_filters( 'smartzine_related_excerpt', wp_trim_words( get_the_excerpt(), 7 ) ); ?>
							</div>
						<?php endif; ?>
					</li>
				<?php endwhile; ?>
			</ul>
		</div><!-- .entry-related -->
	
	<?php endif;

	// Restore original Post Data.
	wp_reset_postdata();

}
endif;

if ( ! function_exists( 'smartzine_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since  1.0.0
 */
function smartzine_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<article id="comment-<?php comment_ID(); ?>" class="comment-container">
			<p <?php hybrid_attr( 'comment-content' ); ?>><?php _e( 'Pingback:', 'smartzine' ); ?> <span <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php comment_author_link(); ?></span></span> <?php edit_comment_link( __( '(Edit)', 'smartzine' ), '<span class="edit-link">', '</span>' ); ?></p>
		</article>
	<?php
			break;
		default :
		// Proceed with normal comments.
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>" <?php hybrid_attr( 'comment' ); ?>>
		<div id="comment-<?php comment_ID(); ?>" class="comment-wrapper">

			<div class="comment-avatar">
				<figure><?php echo get_avatar( $comment, apply_filters( 'smartzine_comment_avatar_size', 64 ) ); ?></figure>
			</div><!-- .comment-avatar -->

			<div class="comment-detail">

				<div class="comment-name number">
					<span class="name" <?php hybrid_attr( 'comment-author' ); ?>><span itemprop="name"><?php echo get_comment_author_link(); ?></span></span>
					<?php
						printf( '<span class="comment-date"><a href="%1$s" ' . hybrid_get_attr( 'comment-permalink' ) . '><time datetime="%2$s" ' . hybrid_get_attr( 'comment-published' ) . '>%3$s</time></a> %4$s</span>',
							esc_url( get_comment_link( $comment->comment_ID ) ),
							get_comment_time( 'c' ),
							/* translators: 1: date, 2: time */
							sprintf( __( '%1$s at %2$s', 'smartzine' ), get_comment_date(), get_comment_time() ),
							sprintf( __( '%1$s&middot; Edit%2$s', 'smartzine' ), '<a href="' . get_edit_comment_link() . '" title="' . esc_attr__( 'Edit Comment', 'smartzine' ) . '">', '</a>' )
						);
					?>
				</div><!-- .comment-name -->
			
				<div class="comment-description" <?php hybrid_attr( 'comment-content' ); ?>>
					<?php if ( '0' == $comment->comment_approved ) : ?>
						<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'smartzine' ); ?></p>
					<?php endif; ?>
					<?php comment_text(); ?>
				</div><!-- .comment-description -->

				<span class="comment-reply">
					<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'smartzine' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
				</span><!-- .reply -->

			</div><!-- comment-detail -->

		</div><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;


if ( ! function_exists( 'smartzine_dynamic_sidebar_class' ) ) :
/**
 * Add has_sidebar to the content area.
 *
 * @since 1.0
 */
function smartzine_dynamic_sidebar_class() {
	if ( current_theme_supports( 'theme-layouts' ) && ! is_admin() ) {
		if ( 'layout-2c-l' == theme_layouts_get_layout() || 'layout-2c-r' == theme_layouts_get_layout() ) {
			echo esc_attr( ' has_sidebar' );
		}
	}
}
endif;

if ( ! function_exists( 'smartzine_posts_layout' ) ) :
/**
 * Custom archive page layout classes.
 *
 * @since  1.0.0
 */
function smartzine_posts_layout() {

	$prefix = 'smartzine-';

	// Get the default layout.
	if ( is_category() ) {
		$layout = smartzine_mod( $prefix . 'cat-layout' );
	} elseif ( is_tag() ) {
		$layout = smartzine_mod( $prefix . 'tag-layout' );
	} elseif ( is_author() ) {
		$layout = smartzine_mod( $prefix . 'author-layout' );
	} elseif ( is_search() ) {
		$layout = smartzine_mod( $prefix . 'search-layout' );
	} else {
		$layout = smartzine_mod( $prefix . 'archive-layout' );
	}

	// Set up empty variable.
	$class = '';

	if ( 'standard' === $layout ) {
		$class = 'post-blog';
	} elseif ( 'list' === $layout ) {
		$class = 'post-list';
	} elseif ( 'grid' === $layout ) {
		$class = 'post-block clearfix';
	} 

	// Allow dev to filter the class.
	echo esc_attr( apply_filters( 'smartzine_archive_page_classes', $class ) );

}
endif;

if ( ! function_exists( 'smartzine_get_first_image' ) ) :
/**
 * Return an HTML img tag for the first image in a post content. Used to draw
 * the content for posts of the “image” format.
 * http://css-tricks.com/snippets/wordpress/get-the-first-image-from-a-post/#comment-1582091 --> not working
 * http://www.wprecipes.com/how-to-get-the-first-image-from-the-post-and-display-it
 *
 * @return string An HTML img tag for the first image in a post content.
 */
function smartzine_get_first_image( $size='full', $echo=true ) {

	if ( has_post_thumbnail() )
		return smartzine_featured_image( array( 'size' => $size ) );

	// Expose information about the current post.
	global $post;

	// We'll trap to see if this stays empty later in the function.
	$src = '';

	// Grab all img src's in the post content
	// $output = preg_match_all( '//i', $post->post_content, $matches ); // not working
	$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);

	// Grab the first img src returned by our regex.
	// if ( ! isset ( $matches[1][0] ) ) { return false; }
	// $src = $matches[1][0];

	// Grab the first <img> complete markup returned by our regex.
	if ( ! isset ( $matches[0][0] ) ) { return false; }
	$src = $matches[0][0];

	// Make sure there's still something worth outputting after sanitization.
	if ( empty( $src ) ) { return false; }

	// add wrapper
	$content = '<div class="entry-image clearfix">';
		$content .= '<a class="img-link" href="' . get_the_permalink() . '">';
			$content .= $src;
		$content .= '</a>';
	$content .= '</div>';

	// choose whether to echo the result or return it as variable
	if ( true == $echo )
		echo $content;
	else
		return $src;

}
endif;

if ( ! function_exists( 'smartzine_get_format_gallery' ) ) :
/**
 * Get the [gallery] shortcode from the post content and display it on index page. It require
 * gallery ids [gallery ids=1,2,3,4] to display it as thumbnail slideshow. If no ids exist it
 * just display it as standard [gallery] markup.
 *
 * If no [gallery] shortcode found in the post content, get the attached images to the post and 
 * display it as slideshow.
 * 
 * @since  1.0.0
 * @uses   get_post_gallery() to get the gallery in the post content.
 * @uses   wp_get_attachment_image() to get the HTML image.
 * @uses   get_children() to get the attached images if no [gallery] found in the post content.
 * @return string
 */
function smartzine_get_format_gallery() {

	// Set up placeholders
	$slider = '';
	$carousel = '';

	// for has_sidebar
	$size = 'medium';

	// for no sidebar
	if ( current_theme_supports( 'theme-layouts' ) && ! is_admin() ) {
		if ( 'layout-1c' == theme_layouts_get_layout() ) {
			$size = 'large';
		}
	}

	// Check the [gallery] shortcode in post content.
	$gallery = get_post_gallery( get_the_ID(), false );

	// Check if the [gallery] exist.
	if ( $gallery ) {

		// Check if the gallery ids exist.
		if ( isset( $gallery['ids'] ) ) {

			// Get the gallery ids and convert it into array.
			$ids = explode( ',', $gallery['ids'] );

			// Display the gallery in a cool slideshow on index page.
			foreach( $ids as $id ) {
				$slider .= '<li class="hentry post">';
				$slider .= '<a class="post-link" rel="prettyPhoto" href="' . wp_get_attachment_url( $id ) . '">';
				$slider .= wp_get_attachment_image( $id, $size, false, array( 'class' => 'entry-thumbnail' ) );
				$slider .= '</a>';
				$slider .= '</li>';

				$carousel .= '<li>';
				$carousel .= wp_get_attachment_image( $id, 'thumbnail', false, array( 'class' => 'entry-thumbnail' ) );
				$carousel .= '</li>';
			}

		} else {

			// If gallery ids not exist, display the standard gallery markup.
			// avoid this, since it'll look bad
			// $html = get_post_gallery( get_the_ID() );

			// if gallery based on images attached to post (only [gallery] in post content)
			// note: in the post content, better to use: [gallery size="large"] or [gallery size="full"]
			$srcs = $gallery['src'];

			// Display the gallery in a cool slideshow on index page.
			foreach( $srcs as $src ) {
				$slider .= '<li class="hentry post">';
				$slider .= '<a class="post-link" rel="prettyPhoto" href="' . esc_url( $src ) . '">';
				$slider .= '<img src="' . esc_url( $src ) . '" />';
				$slider .= '</a>';
				$slider .= '</li>';

				$carousel .= '<li>';
				$carousel .= '<img src="' . esc_url( $src ) . '" />';
				$carousel .= '</li>';
			}

		}

	// If no [gallery] in post content, get attached images to the post.
	} else {

		// Set up default arguments.
		$defaults = array( 
			'order'          => 'ASC',
			'post_type'      => 'attachment',
			'post_parent'    => get_the_ID(),
			'post_mime_type' => 'image',
			'numberposts'    => -1
		);

		// Retrieves attachments from the post.
		$attachments = get_children( apply_filters( 'smartzine_gallery_format_args', $defaults ) );

		// Check if attachments exist.
		if ( $attachments ) {

			// Display the attachment images in a cool slideshow on index page.
			foreach ( $attachments as $attachment ) {
				$slider .= '<li class="hentry post">';
				$slider .= '<a class="post-link" rel="prettyPhoto" href="' . wp_get_attachment_url( $attachment->ID ) . '">';
				$slider .= wp_get_attachment_image( $attachment->ID, $size, false, array( 'class' => 'entry-thumbnail' ) );
				$slider .= '</a>';
				$slider .= '</li>';

				$carousel .= '<li>';
				$carousel .= wp_get_attachment_image( $attachment->ID, 'thumbnail', false, array( 'class' => 'entry-thumbnail' ) );
				$carousel .= '</li>';
			}

		} else {

			// if no [gallery] shortcode and has no attachments, bail them out
			return;

		}

	}
	?>
	<div class="entry-image clearfix">

		<div id="single-slider" class="flexslider">
			<ul class="slides">
				<?php echo $slider; ?>
			</ul>
		</div><!-- #single-slider -->

		<div id="carousel" class="flexslider">
			<ul class="slides">
				<?php echo $carousel; ?>
			</ul>
		</div><!-- #carousel -->

	</div><!-- .entry-image -->
	<?php
}
endif;

if ( ! function_exists( 'smartzine_get_post_format_link_url' ) ) :
/**
 * Forked from hybrid_get_the_post_format_url.
 * Filters 'get_the_post_format_url' to make for a more robust and back-compatible function.  If WP did 
 * not find a URL, check the post content for one.  If nothing is found, return the post permalink.
 * Used in Post Format Link
 *
 * @since 1.0.0
 */
function smartzine_get_post_format_link_url( $url = '', $post = null ) {

	if ( empty( $url ) ) {

		$post = is_null( $post ) ? get_post() : $post;

		/* Catch links that are not wrapped in an '<a>' tag. */
		$content_url = preg_match( '/<a\s[^>]*?href=[\'"](.+?)[\'"]/is', make_clickable( $post->post_content ), $matches );

		$content_url = ! empty( $matches[1] ) ? esc_url_raw( $matches[1] ) : '';

		$url = ! empty( $content_url ) ? $content_url : get_permalink( get_the_ID() );
	}

	if ( $url ) {
	?>
		<h2 class="entry-title">
			<a href="<?php echo esc_url( $url ); ?>" itemprop="url">
				<?php if ( get_the_title() && ( __( '(Untitled)', 'smartzine' ) != get_the_title() ) ) { ?>
					<?php the_title(); ?>
				<?php } else { ?>
					<?php echo esc_attr( $url ); ?>
				<?php }	?>
			</a>
		</h2>
	<?php
	}
	
}
endif;

if ( ! function_exists( 'smartzine_content_slider' ) ) :
/**
 * Content Slider
 */
function smartzine_content_slider( $args = array() ) {

	$defaults = array(
		'id'    => 'archive'
	);
	
	// Parse incoming $args into an array and merge it with $defaults
	$args = wp_parse_args( $args, $defaults );
	extract( $args );

	// Check if it enabled.
	if ( ! $enable )
		return;

	// Posts query arguments.
	$args = array(
		'post_type'           => 'post',
		'posts_per_page'      => absint( $num ),
		'orderby'             => $orderby,
		'ignore_sticky_posts' => 1
	);

	// Limit to tag based on user selected tag.
	if ( ! empty( $tag ) ) {
		$args['tag_id'] = $tag;
	}

	// Allow dev to filter the post arguments.
	$query = apply_filters( 'smartzine_slider_args', $args );

	// The post query.
	$slider = new WP_Query( $query );

	if ( $slider->have_posts() ) :
?>
		<?php if ( $title ) : ?><h3 class="heading"><?php echo $title; ?></h3><?php endif; ?>
		<div id="<?php echo esc_attr( $id ); ?>-slider" class="flexslider">
			<ul class="slides">

				<?php while ( $slider->have_posts() ) : $slider->the_post(); ?>
					<?php get_template_part( 'content', 'slider' ); ?>
				<?php endwhile; ?>

			</ul><!-- .slides -->
		</div><!-- #xx-slider -->
	<?php
	endif;

	wp_reset_postdata();
}
endif;

if ( ! function_exists( 'smartzine_review_box' ) ) :
/**
 * Review Box
 */
function smartzine_review_box( $args ) {

	$defaults = array(
 		'show' => true
	);
	// Parse incoming $args into an array and merge it with $defaults
	$args = wp_parse_args( $args, $defaults );
	extract( $args );

	// return if not enabled
	if ( ! $show )
		return;

	if ( has_post_thumbnail() ) :

		// get data from WP-PostRatings
		// https://wordpress.org/plugins/wp-postratings/
		$post_ratings_data = get_post_custom( get_the_ID() );

		$post_ratings_average = is_array( $post_ratings_data ) && array_key_exists( 'ratings_average', $post_ratings_data ) ? floatval( $post_ratings_data['ratings_average'][0] ) : 0;

		$post_ratings_average = number_format_i18n( $post_ratings_average, 1 );

		// bail out if haven't been rated
		if ( 0 == $post_ratings_average )
			return;
	?>
		<div class="review-box">
			<span class="score"><?php echo esc_attr( $post_ratings_average ); ?></span>
			<span class="text"><?php _e( 'score', 'smartzine' ); ?></span>
		</div>
	<?php
	endif;
}
endif;

if ( ! function_exists( 'smartzine_featured_boxes' ) ) :
/**
 * Home Featured
 */
function smartzine_featured_boxes( $args = array() ) {

	$defaults = array(
		'enable' => true,
	);
	
	// Parse incoming $args into an array and merge it with $defaults
	$args = wp_parse_args( $args, $defaults );
	extract( $args );

	// Check if it enabled.
	if ( ! $enable )
		return;

	// Posts query arguments.
	$args = array(
		'post_type'           => 'post',
		'orderby'             => $orderby,
		'posts_per_page'      => 3,
		'ignore_sticky_posts' => 1
	);

	// Limit to tag based on user selected tag.
	if ( ! empty( $tag ) ) {
		$args['tag_id'] = $tag;
	}

	// Allow dev to filter the post arguments.
	$query = apply_filters( 'smartzine_featured_boxes_args', $args );

	// The post query.
	$featured = new WP_Query( $query );

	if ( $featured->have_posts() ) :
		$i = 0;
?>
	<?php while ( $featured->have_posts() ) : $featured->the_post(); ?>
		<?php
		if ( 0 == $i ) {
			$class = 'featured-big';
			$size = 'medium';
		} elseif ( 1 == $i ) {
			$class = 'featured-small';
			$size = 'post-thumbnail';
		} elseif ( 2 == $i ) {
			$class = 'featured-small last';
			$size = 'post-thumbnail';
		}
		?>
		<div class="<?php echo esc_attr( $class ); ?>">
			<a class="post-link" href="<?php the_permalink(); ?>">
				<?php if ( has_post_thumbnail() ) : ?>
					<?php the_post_thumbnail( $size, array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
				<?php else : ?>
					<img class="entry-thumbnail" src="<?php echo esc_url( '//placehold.it/620x420/?text=' . urlencode( get_the_title() ) ); ?>" alt="<?php the_title_attribute(); ?>" />
				<?php endif; ?>
			</a>
			<div class="featured-text">
				<?php smartzine_entry_category( array( 'show' => true ) ); ?>
				<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" itemprop="url" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
			</div>
			<a href="<?php the_permalink(); ?>"><div class="featured-overlay"></div></a>
		</div><!-- .featured-xx -->
	<?php $i++; endwhile; ?>
	<?php
	endif;
	wp_reset_postdata();

}
endif;

if ( ! function_exists( 'smartzine_home_featured' ) ) :
/**
 * Home Featured
 */
function smartzine_home_featured() {

	// Theme prefix
	$prefix = 'smartzine-';

	// Get the customizer value.
	$layout = smartzine_mod( $prefix . 'home-featured-layout' );
	$featured_args = array(
		'enable'  => smartzine_mod( $prefix . 'home-featured-enable' ),
		'tag'     => smartzine_mod( $prefix . 'home-featured-tag' ),
		'orderby' => smartzine_mod( $prefix . 'home-featured-orderby' ),

		// used in slider layout
		'title'  => false,
		'num'    => smartzine_mod( $prefix . 'home-featured-num' ),
		'id'     => 'featured'
	);
	if ( $featured_args['enable'] ) :
	?>
		<div id="featured-content" class="clearfix">
			<?php 
			if ( 'boxes' == $layout )
				smartzine_featured_boxes( $featured_args );
			elseif ( 'slider' == $layout )
				smartzine_content_slider( $featured_args ); 
			?>
		</div>
	<?php
	endif;
}
endif;

if ( ! function_exists( 'smartzine_home_widget_title_link' ) ) :
/**
 * Home Widgets Title Link
 */
function smartzine_home_widget_title_link( $instance ) {

	if ( $instance['cat'] ) {

		// Get the category archive link.
		$title_link = get_category_link( $instance['cat'] );

	} elseif ( $instance['format'] ) {

		// Get the post format archive link
		$title_link = get_post_format_link( $instance['format'] );

	} elseif ( get_option( 'page_for_posts' ) ) {

		// 'page_for_posts' link
		$title_link = get_permalink( get_option( 'page_for_posts' ) );

	} else {

		// just throw to home
		$title_link = home_url( '/' );

	}

	return $title_link;

}
endif;