<?php
/**
 * Home Grid/List widget.
 *
 * @package    SmartZine
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class SmartZine_Home_Grid_List_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget-smartzine-home-gridlist',
			'description' => __( 'Widget to display custom posts in grid/list layout. Please only use it on home page/home sidebar.', 'smartzine' )
		);

		// Create the widget.
		parent::__construct(
			'smartzine-home-gridlist',                   // $this->id_base
			__( '&raquo; Home Grid/List', 'smartzine' ), // $this->name
			$widget_options                              // $this->widget_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

			// Theme prefix
			$prefix = 'smartzine-';

			// Posts query arguments.
			$args = array(
				'post_type'      => 'post',
				'posts_per_page' => (int) $instance['limit']
			);

			// Limit to category based on user selected.
			if ( ! $instance['cat'] == 0 ) {
				$args['cat'] = $instance['cat'];
			}

			// limit post formats
			if ( ! $instance['format'] == 0 ) {
				$args['tax_query'] = array(
					array(
						'taxonomy' => 'post_format',
						'field'    => 'slug',
						'terms'    => array( 'post-format-' . $instance['format'] )
					),
				);
			}

			// Allow dev to filter the post arguments.
			$query = apply_filters( 'smartzine_home_gridlist_args', $args );

			// The post query.
			$posts = new WP_Query( $query );

			if ( $posts->have_posts() ) : ?>
				
				<?php
					if ( $instance['title'] ) {
						echo $before_title . '<a href="' . esc_url( smartzine_home_widget_title_link( $instance ) ) . '">' . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . '</a>' . $after_title;
					}

					$class = ( 'list' == $instance['layout'] ) ? 'post-list' : 'post-block';

					$i = 1; // counter for blog grid
				?>
				<div class="<?php echo $class; ?>">

					<?php while ( $posts->have_posts() ) : $posts->the_post(); ?>

						<?php
						// 'last' class for Blog Grid
						$classes = array();
						if ( 'grid' == $instance['layout'] ) {
							if ( 'layout-1c' == theme_layouts_get_layout() ) 
								$divider = 3;
							else
								$divider = 2;

							if ( 0 == ( $i % $divider ) )
								$classes[] = 'last';
							$i++;
						}
						?>
						
						<article <?php post_class( $classes ); ?>>

							<a href="<?php the_permalink(); ?>" class="post-link" rel="bookmark" itemprop="url">
								<?php smartzine_featured_image( array( 'size' => 'post-thumbnail', 'show' => $instance['showthumb'] ) ); ?>
								<?php smartzine_post_icon( array( 'layout' => $instance['layout'], 'show' => $instance['showthumb'] ) ); ?>
								<?php smartzine_review_box( array( 'show' => $instance['showreview'] ) ); ?>
							</a>

							<?php smartzine_entry_category( array( 'show' => $instance['showcat'] ) ); ?>

							<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>

							<?php if ( $instance['showexcerpt'] ) : ?>
								<div class="entry-summary">
									<?php echo strip_tags( wp_trim_words( get_the_excerpt(), (int) $instance['excerpt_limit'] ) ); ?>
								</div><!-- .entry-summary -->
							<?php endif; ?>

							<?php smartzine_post_meta( array( 'show' => $instance['showmeta'] ) ); ?>
							
						</article><!-- .hentry .post -->	

					<?php endwhile; ?>

				</div>

			<?php endif;

			// Restore original Post Data.
			wp_reset_postdata();

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['title']     = strip_tags( $new_instance['title'] );
		$instance['layout']    = strip_tags( $new_instance['layout'] );
		$instance['limit']     = (int) $new_instance['limit'];
		$instance['cat']       = (int) $new_instance['cat'];
		$instance['format']    = strip_tags( $new_instance['format'] );
		$instance['showthumb']   = isset( $new_instance['showthumb'] ) ? (bool) $new_instance['showthumb'] : false;
		$instance['showcat']   = isset( $new_instance['showcat'] ) ? (bool) $new_instance['showcat'] : false;
		$instance['showexcerpt'] = isset( $new_instance['showexcerpt'] ) ? (bool) $new_instance['showexcerpt'] : false;
		$instance['excerpt_limit']     = (int) $new_instance['excerpt_limit'];
		$instance['showmeta']   = isset( $new_instance['showmeta'] ) ? (bool) $new_instance['showmeta'] : false;
		$instance['showreview']   = isset( $new_instance['showreview'] ) ? (bool) $new_instance['showreview'] : false;

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'title'         => '',
			'layout'        => 'grid',
			'limit'         => 3,
			'cat'           => '',
			'format'        => '',
			'showthumb'     => true,
			'showcat'       => true,
			'showexcerpt'   => true,
			'excerpt_limit' => 15,
			'showmeta'      => true,
			'showreview'    => true
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php _e( 'Title:', 'smartzine' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'layout' ); ?>"><?php _e( 'Choose Layout', 'smartzine' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'layout' ); ?>" name="<?php echo $this->get_field_name( 'layout' ); ?>" style="width:100%;">
				<option value="grid" <?php selected( $instance['layout'], 'grid' ); ?>><?php _e( 'Grid', 'smartzine' ); ?></option>
				<option value="list" <?php selected( $instance['layout'], 'list' ); ?>><?php _e( 'List', 'smartzine' ); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'limit' ); ?>">
				<?php _e( 'Number of posts to show', 'smartzine' ); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>" type="number" step="1" min="0" value="<?php echo (int)( $instance['limit'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'cat' ); ?>"><?php _e( 'Choose Category', 'smartzine' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'cat' ); ?>" name="<?php echo $this->get_field_name( 'cat' ); ?>" style="width:100%;">
				<?php $categories = get_terms( 'category' ); ?>
				<option value="0"><?php _e( 'All categories &hellip;', 'smartzine' ); ?></option>
				<?php foreach( $categories as $category ) { ?>
					<option value="<?php echo esc_attr( $category->term_id ); ?>" <?php selected( $instance['cat'], $category->term_id ); ?>><?php echo esc_html( $category->name ); ?></option>
				<?php } ?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'format' ); ?>"><?php _e( 'Choose Post Format', 'smartzine' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'format' ); ?>" name="<?php echo $this->get_field_name( 'format' ); ?>" style="width:100%;">
				<?php $categories = get_terms( 'category' ); ?>
				<?php $post_formats = get_theme_support( 'post-formats' ); ?>
				<option value="0"><?php _e( 'All Post Formats', 'smartzine' ); ?></option>
				<?php foreach( $post_formats[0] as $post_format ) { ?>
					<option value="<?php echo esc_attr( $post_format ); ?>" <?php selected( $instance['format'], $post_format ); ?>><?php echo esc_html( ucfirst( $post_format ) ); ?></option>
				<?php } ?>
			</select>
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['showthumb'] ); ?> id="<?php echo $this->get_field_id( 'showthumb' ); ?>" name="<?php echo $this->get_field_name( 'showthumb' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'showthumb' ); ?>">
				<?php _e( 'Display thumbnail?', 'smartzine' ); ?>
			</label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['showcat'] ); ?> id="<?php echo $this->get_field_id( 'showcat' ); ?>" name="<?php echo $this->get_field_name( 'showcat' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'showcat' ); ?>">
				<?php _e( 'Display post category?', 'smartzine' ); ?>
			</label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['showexcerpt'] ); ?> id="<?php echo $this->get_field_id( 'showexcerpt' ); ?>" name="<?php echo $this->get_field_name( 'showexcerpt' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'showexcerpt' ); ?>">
				<?php _e( 'Display excerpt?', 'smartzine' ); ?>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'excerpt_limit' ); ?>">
				<?php _e( 'Excerpt limit', 'smartzine' ); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'excerpt_limit' ); ?>" name="<?php echo $this->get_field_name( 'excerpt_limit' ); ?>" type="number" step="1" min="0" value="<?php echo (int)( $instance['excerpt_limit'] ); ?>" />
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['showmeta'] ); ?> id="<?php echo $this->get_field_id( 'showmeta' ); ?>" name="<?php echo $this->get_field_name( 'showmeta' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'showmeta' ); ?>">
				<?php _e( 'Display post meta?', 'smartzine' ); ?>
			</label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['showreview'] ); ?> id="<?php echo $this->get_field_id( 'showreview' ); ?>" name="<?php echo $this->get_field_name( 'showreview' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'showreview' ); ?>">
				<?php _e( 'Display review?', 'smartzine' ); ?>
			</label>
		</p>

	<?php

	}

}