<?php
/**
 * Home Slider widget.
 *
 * @package    SmartZine
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class SmartZine_Home_Slider_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget-smartzine-home-slider',
			'description' => __( 'Widget to display custom posts list in slider. Please only use it on home page/home sidebar.', 'smartzine' )
		);

		// Create the widget.
		parent::__construct(
			'smartzine-home-slider',          // $this->id_base
			__( '&raquo; Home Slider', 'smartzine' ), // $this->name
			$widget_options                      // $this->widget_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

			// Theme prefix
			$prefix = 'smartzine-';

			// Posts query arguments.
			$args = array(
				'post_type'      => 'post',
				'posts_per_page' => (int) $instance['limit']
			);

			// Limit to category based on user selected.
			if ( ! $instance['cat'] == 0 ) {
				$args['cat'] = $instance['cat'];
			}

			// limit post formats
			if ( ! $instance['format'] == 0 ) {
				$args['tax_query'] = array(
					array(
						'taxonomy' => 'post_format',
						'field'    => 'slug',
						'terms'    => array( 'post-format-' . $instance['format'] )
					),
				);
			}

			// Allow dev to filter the post arguments.
			$query = apply_filters( 'smartzine_home_slider_args', $args );

			// The post query.
			$posts = new WP_Query( $query );

			if ( $posts->have_posts() ) : ?>
				
				<?php
					if ( $instance['title'] ) {
						echo $before_title . '<a href="' . esc_url( smartzine_home_widget_title_link( $instance ) ) . '">' . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . '</a>' . $after_title;
					}
				?>
				<div id="content-slider" class="flexslider">
					<ul class="slides">

						<?php while ( $posts->have_posts() ) : $posts->the_post(); ?>
							
							<li class="hentry post">
								<a class="post-link" href="<?php the_permalink(); ?>">
									<?php if ( has_post_thumbnail() ) : ?>
										<?php the_post_thumbnail( 'large', array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
									<?php else : ?>
										<img class="entry-thumbnail" width="940" height="540" src="<?php echo esc_url( '//placehold.it/940x540/?text=' . urlencode( get_the_title() ) ); ?>" alt="<?php the_title_attribute(); ?>" />
									<?php endif; ?>
								</a>
								<div class="featured-text">
									<?php smartzine_entry_category( array( 'show' => $instance['showcat'] ) ); ?>
									<?php if ( $instance['showtitle'] ) : ?>
										<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" itemprop="url" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
									<?php endif; ?>
								</div>
								<a href="<?php the_permalink(); ?>"><div class="featured-overlay"></div></a>
							</li>

						<?php endwhile; ?>

					</ul>
				</div>

			<?php endif;

			// Restore original Post Data.
			wp_reset_postdata();

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['title']     = strip_tags( $new_instance['title'] );
		$instance['limit']     = (int) $new_instance['limit'];
		$instance['cat']       = (int) $new_instance['cat'];
		$instance['format']    = strip_tags( $new_instance['format'] );
		$instance['showcat']   = isset( $new_instance['showcat'] ) ? (bool) $new_instance['showcat'] : false;
		$instance['showtitle'] = isset( $new_instance['showtitle'] ) ? (bool) $new_instance['showtitle'] : false;

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'title'     => '',
			'limit'     => 5,
			'cat'       => '',
			'format'      => '',
			'showcat'   => true,
			'showtitle' => true
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php _e( 'Title:', 'smartzine' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'limit' ); ?>">
				<?php _e( 'Number of posts to show', 'smartzine' ); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'limit' ); ?>" name="<?php echo $this->get_field_name( 'limit' ); ?>" type="number" step="1" min="0" value="<?php echo (int)( $instance['limit'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'cat' ); ?>"><?php _e( 'Choose Category', 'smartzine' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'cat' ); ?>" name="<?php echo $this->get_field_name( 'cat' ); ?>" style="width:100%;">
				<?php $categories = get_terms( 'category' ); ?>
				<option value="0"><?php _e( 'All categories &hellip;', 'smartzine' ); ?></option>
				<?php foreach( $categories as $category ) { ?>
					<option value="<?php echo esc_attr( $category->term_id ); ?>" <?php selected( $instance['cat'], $category->term_id ); ?>><?php echo esc_html( $category->name ); ?></option>
				<?php } ?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'format' ); ?>"><?php _e( 'Choose Post Format', 'smartzine' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'format' ); ?>" name="<?php echo $this->get_field_name( 'format' ); ?>" style="width:100%;">
				<?php $categories = get_terms( 'category' ); ?>
				<?php $post_formats = get_theme_support( 'post-formats' ); ?>
				<option value="0"><?php _e( 'All Post Formats', 'smartzine' ); ?></option>
				<?php foreach( $post_formats[0] as $post_format ) { ?>
					<option value="<?php echo esc_attr( $post_format ); ?>" <?php selected( $instance['format'], $post_format ); ?>><?php echo esc_html( ucfirst( $post_format ) ); ?></option>
				<?php } ?>
			</select>
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['showcat'] ); ?> id="<?php echo $this->get_field_id( 'showcat' ); ?>" name="<?php echo $this->get_field_name( 'showcat' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'showcat' ); ?>">
				<?php _e( 'Display post category?', 'smartzine' ); ?>
			</label>
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['showtitle'] ); ?> id="<?php echo $this->get_field_id( 'showtitle' ); ?>" name="<?php echo $this->get_field_name( 'showtitle' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'showtitle' ); ?>">
				<?php _e( 'Display post title?', 'smartzine' ); ?>
			</label>
		</p>

	<?php

	}

}