<?php
/**
 * Home Special widget.
 *
 * @package    SmartZine
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */
class SmartZine_Home_Special_Widget extends WP_Widget {

	/**
	 * Sets up the widgets.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		// Set up the widget options.
		$widget_options = array(
			'classname'   => 'widget-smartzine-home-special three-col-posts',
			'description' => __( 'Widget to display custom posts list in special three column posts. Please only use it on home page/home sidebar.', 'smartzine' )
		);

		// Create the widget.
		parent::__construct(
			'smartzine-home-special',                  // $this->id_base
			__( '&raquo; Home Special', 'smartzine' ), // $this->name
			$widget_options                            // $this->widget_options
		);
	}

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 *
	 * @since 1.0.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Output the theme's $before_widget wrapper.
		echo $before_widget;

			// Theme prefix
			$prefix = 'smartzine-';

			// Posts query arguments.
			$args = array(
				'post_type'      => 'post',
				'posts_per_page' => 8
			);

			// Limit to category based on user selected.
			if ( ! $instance['cat'] == 0 ) {
				$args['cat'] = $instance['cat'];
			}

			// limit post formats
			if ( ! $instance['format'] == 0 ) {
				$args['tax_query'] = array(
					array(
						'taxonomy' => 'post_format',
						'field'    => 'slug',
						'terms'    => array( 'post-format-' . $instance['format'] )
					),
				);
			}

			// Allow dev to filter the post arguments.
			$query = apply_filters( 'smartzine_home_special_args', $args );

			// The post query.
			$posts = new WP_Query( $query );

			if ( $posts->have_posts() ) : ?>
				
				<?php
					if ( $instance['title'] ) {
						echo $before_title . '<a href="' . esc_url( smartzine_home_widget_title_link( $instance ) ) . '">' . apply_filters( 'widget_title', $instance['title'], $instance, $this->id_base ) . '</a>' . $after_title;
					}
					$i = 0;
				?>

				<?php while ( $posts->have_posts() ) : $posts->the_post(); ?>

					<?php if ( 0 == $i ) { ?><div class="col-one"><?php } ?>

					<?php if ( 1 == $i ) { ?><div class="col-two"><?php } ?>

					<?php if ( 3 == $i ) { ?><div class="col-three"><h3><?php _e( 'More Posts', 'smartzine' ); ?></h3><ul><?php } ?>

					<?php if ( 2 < $i ) { ?>
						<li <?php post_class(); ?>>
					<?php } else { ?>
						<?php $classes = ( 2 == $i ) ? array( 'last' ) : array(); ?>
						<article <?php post_class( $classes ); ?>>
					<?php } ?>

						<?php if ( 3 > $i ) : ?>
							<a href="<?php the_permalink(); ?>" class="post-link" rel="bookmark" itemprop="url">
								<?php $size = ( 0 == $i ) ? 'smartzine-threecolposts-big' : 'smartzine-threecolposts-small'; ?>
								<?php if ( has_post_thumbnail() ) : ?>
									<?php the_post_thumbnail( $size, array( 'class' => 'entry-thumbnail', 'alt' => esc_attr( get_the_title() ) ) ); ?>
								<?php else : ?>
									<img class="entry-thumbnail" src="<?php echo esc_url( '//placehold.it/940x540/?text=' . urlencode( get_the_title() ) ); ?>" alt="<?php the_title_attribute(); ?>" />
								<?php endif; ?>
								<?php smartzine_post_icon(); ?>
								<?php smartzine_review_box( array( 'show' => $instance['showreview'] ) ); ?>
							</a>

							<?php smartzine_entry_category( array( 'show' => true ) ); ?>
						<?php endif; ?>

						<?php the_title( sprintf( '<h2 class="entry-title" ' . hybrid_get_attr( 'entry-title' ) . '><a href="%s" rel="bookmark" itemprop="url">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>

						<?php if ( 0 == $i ) : ?>
							<div class="entry-summary">
								<?php the_excerpt(); ?>
							</div><!-- .entry-summary -->
						<?php endif; ?>

						<?php 
						if ( 0 == $i ) {
							smartzine_post_meta( array( 'show' => true ) ); 
						} elseif ( 2 < $i ) {
							echo '<span class="entry-meta">';
							smartzine_posted_on();
							echo '</span>';
						}
						?>
					
					<?php if ( 2 < $i ) { ?>
						</li>
					<?php } else { ?>
						</article>
					<?php } ?>

					<?php if ( ( 7 == $i ) || 
						// if total posts more than 3 but not reaching 8
						( ( $posts->post_count > 3 ) && ( $posts->post_count - 1 == $i ) ) ) { ?>
						</ul>
					<?php } ?>

					<?php if ( ( 0 == $i ) || ( 2 == $i ) || ( 7 == $i ) || 
						( $posts->post_count - 1 == $i ) ) { // if total posts not reaching 3 or 8 ?>
						</div>
					<?php } ?>

				<?php $i++; endwhile; ?>

			<?php endif;

			// Restore original Post Data.
			wp_reset_postdata();

		// Close the theme's widget wrapper.
		echo $after_widget;

	}

	/**
	 * Updates the widget control options for the particular instance of the widget.
	 *
	 * @since 1.0.0
	 */
	function update( $new_instance, $old_instance ) {

		$instance = $new_instance;

		$instance['title']     = strip_tags( $new_instance['title'] );
		$instance['cat']       = (int) $new_instance['cat'];
		$instance['format']    = strip_tags( $new_instance['format'] );
		$instance['showreview']   = isset( $new_instance['showreview'] ) ? (bool) $new_instance['showreview'] : false;

		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 *
	 * @since 1.0.0
	 */
	function form( $instance ) {

		// Default value.
		$defaults = array(
			'title'      => '',
			'cat'        => '',
			'format'     => '',
			'showreview' => true
		);

		$instance = wp_parse_args( (array) $instance, $defaults );
	?>

		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">
				<?php _e( 'Title:', 'smartzine' ); ?>
			</label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'cat' ); ?>"><?php _e( 'Choose Category', 'smartzine' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'cat' ); ?>" name="<?php echo $this->get_field_name( 'cat' ); ?>" style="width:100%;">
				<?php $categories = get_terms( 'category' ); ?>
				<option value="0"><?php _e( 'All categories &hellip;', 'smartzine' ); ?></option>
				<?php foreach( $categories as $category ) { ?>
					<option value="<?php echo esc_attr( $category->term_id ); ?>" <?php selected( $instance['cat'], $category->term_id ); ?>><?php echo esc_html( $category->name ); ?></option>
				<?php } ?>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id( 'format' ); ?>"><?php _e( 'Choose Post Format', 'smartzine' ); ?></label>
			<select class="widefat" id="<?php echo $this->get_field_id( 'format' ); ?>" name="<?php echo $this->get_field_name( 'format' ); ?>" style="width:100%;">
				<?php $categories = get_terms( 'category' ); ?>
				<?php $post_formats = get_theme_support( 'post-formats' ); ?>
				<option value="0"><?php _e( 'All Post Formats', 'smartzine' ); ?></option>
				<?php foreach( $post_formats[0] as $post_format ) { ?>
					<option value="<?php echo esc_attr( $post_format ); ?>" <?php selected( $instance['format'], $post_format ); ?>><?php echo esc_html( ucfirst( $post_format ) ); ?></option>
				<?php } ?>
			</select>
		</p>

		<p>
			<input class="checkbox" type="checkbox" <?php checked( $instance['showreview'] ); ?> id="<?php echo $this->get_field_id( 'showreview' ); ?>" name="<?php echo $this->get_field_name( 'showreview' ); ?>" />
			<label for="<?php echo $this->get_field_id( 'showreview' ); ?>">
				<?php _e( 'Display review?', 'smartzine' ); ?>
			</label>
		</p>

	<?php

	}

}